<?php

    /***************************************************************************
    *                            Dolphin Smart Community Builder
    *                              -------------------
    *     begin                : Mon Mar 23 2006
    *     copyright            : (C) 2007 BoonEx Group
    *     website              : http://www.boonex.com
    * This file is part of Dolphin - Smart Community Builder
    *
    * Dolphin is free software; you can redistribute it and/or modify it under
    * the terms of the GNU General Public License as published by the
    * Free Software Foundation; either version 2 of the
    * License, or  any later version.
    *
    * Dolphin is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
    * without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    * See the GNU General Public License for more details.
    * You should have received a copy of the GNU General Public License along with Dolphin,
    * see license.txt file; if not, write to marketing@boonex.com
    ***************************************************************************/

    /**
     * Member menu
     *
     * Related classes: 
     *  @see BxBaseMemberMenu        - member menu base representation 
     *  @see BxTemplMemberMenu       - member menu template representation 
     *  
     * To add a new menu item, you need to navigate to "admin/member_menu_compose.php" through web interface where you can do it.
     * If you need to add a specific menu item, you will find the whole list of menu properties below.
     * Table structure - `sys_menu_member`;
     *
     * `Caption`     - menu caption;
     * `Name`        - menu item name (to be used in the Admin Panel);
     * `Icon`        - menu icon (to be displayed in the menu);
     * `Link`        - URL assigned to the menu item;
     * `Script`      - javascript code (an onclick event will be created);
     * `Eval`        - system field (you can find its explanation below);
     * `PopupMenu`   - use it when you need to create a drop-down list for the menu item (below you will find an example);
     * `Order`       - sorting;
     * `Active`      - this field can have "0" or "1" which stands for "invisible" and "visible" respectively;
     * `Editable`    - this field can have "0" or "1" thus being ineditable or editable respectively in the Admin Panel;
     * `Deletable`   - this field can have "0" or "1" thus being undeletable or deletable (respectively) through the Admin Panel web interface;
     * `Target`      - the "target" attribute for the link (for example, "_blank" will open the link in a new window);
     * `Position`    - menu item position (it can have one of the two values: 'top' to place the menu item in the left position on the menu, 'top_extra' to place the item in the right position on the menu);
     * `Type`        - menu type (it can be one of these three types: 'link','system','linked_item'). 'link' - is an ordinary link, 'system' - this menu item will be created by the function specified in the `Eval` field` ????, 'linked_item' - a child element of the menu item (see an example below);
     * `Parent`      - this field specifies the parent of the menu item (it is usually used together with the `linked_item` menu type),
     * `Bubble`      - a special field which enables drawing different events notifiers next to the menu item (see an example below),
     * `Description` - menu item description (when hovering over the menu item with a mouse, a block with this description will be displayed below the menu item; this field is language keys based)
     *
     *
     * Example of usage:
     * 
     * 1. Example of using the `Eval` field:
     *      - for example, you need to append a member's ID to the URL specified in the `Link` field;
     *          so, you need to change the URL in the `Link` field in the following way:
     *          http://my.com?ID={evalResult} (here the marker {evalResult} will be replaced with the function output
     *          Then you create a function in the `Eval` field:
     *          return (isset($_COOKIE['memberID']) && isMember() ) ? (int) $_COOKIE['memberID'] : 0;        
     *
     * 2. Example of using the `PopupMenu` field
     *        - assume you need to create a `News` menu item and create a drop-down block in it which would display some information.
     *              To do so, you first need to run an SQL query which will insert data into the appropriate fields:
     *            ...`Caption` = '_News', `Link` = 'news.php'... and then specify some code in the `PopupMenu` field which will create the contents of the current menu:
     *              
     *              //example of PHP code into `PopupMenu` field;  
     *               require_once('News.php');
     *               return getNewsSubMenu();
     *                   
     * 3. Example of using the `Bubble` field (system notifiers)
     *      - assume you need your menu item to display the number of mails in real time (i.e. if someone has written you a mail, you would be notified immediately),
     *      to do so, you need to create a menu item as in the previous example and create a function in the `Bubble` field which will request the mail script for any changes: 
     *
     *       bx_import('BxTemplMailBox');
     *       // return list of new messages ;
     *       $aRetEval= BxTemplMailBox::get_member_menu_bubble_new_messages({ID}, {iOldCount});
     * 
     *       where $aRetEval is an array which will be processed  (it shouldn't be renamed!!!)
     *       the first parameter {ID} is Profile's ID, the second parameter is the number of mails retrieved during the previous iteration.
     *       
     *       the function will return an array looking like this:
     *
     *           $aRetEval = array(
     *               'count'     => $iNewMessages,
     *               'messages'  => $aNotifyMessages,
     *           );
     *           
     *       where 'count' is the whole number of mails, 'messages' is an array of messages;
     *       @see BxTemplMailBox::get_member_menu_bubble_new_messages;
     *
     * 4. Example of using the 'linked_item' type field
     *       - For example, you need to append your menu item to already existing one, for example to the `profile` menu item
     *       To do so, specify the name of your module in the `Name` field (for example 'maps'). Then put a PHP code in the `Eval` field;
     *       it will form the content of your menu item ( @see BxDolService::serviceGetMemberMenuLink )
     *       in the `Parent` field specify the ID of the item you need to append your item to and specify 'linked_item' in the `Type` field
     *
     * Memberships/ACL:
     * no levels
     *
     *
     * 
     * Alerts:
     * no alerts
     */
    class BxDolMemberMenu 
    {
        // contain all registered menu's bubbles;
        var $sBubbles = null;

        // contain current menu possition (allowed values : top, bottom, fixed)
        var $sMemberMenuPosition = null;

        var $sMenuCacheFile      = null;

        var $iBubblesUpdateTime  = 6000; // in milliseconds;

        var $iNotifyDestroyTime  = 3000; // in milliseconds;

        // page that will procces all ajax queries from member menu ;
        var $sQueryPageReciver = 'member_menu_queries.php';

        var $sBubblePrefix = 'bubble_';

        /**
         * Class constructor;
         *
         */
        function BxDolMemberMenu()
        {
            $this -> sMenuCacheFile = BX_DIRECTORY_PATH_DBCACHE . 'sys_menu_member.inc';

            $this -> sMemberMenuPosition = ( isset($_COOKIE['menu_position']) ) 
                ? $_COOKIE['menu_position']
                : getParam( 'ext_nav_menu_top_position' );
        }

        /**
         * Function will generate extra sub menu item;
         *
         * @param : $aLinkInfo (array);
                ['item_link']       - (string) module's URL;
                ['item_onclick']    - (string) if isset this value that script will generate onclick param into link;
                ['item_title']      - (string) module's title;
                ['extra_info']      - (string) module's extra info (fore exmaple: number of polls);
                ['item_img_src']    - (string) module's icon's URL;
                ['item_img_alt']    - (string) module's icon's alt text;
                ['item_img_width']  - (integer) module's icon's width;
                ['item_img_height'] - (integer) module's icon's height;
         */
        function getGetExtraMenuLink(&$aLinkInfo)
        {
            global $oSysTemplate;

            $aTemplateKeys = array(
                'bx_if:item_img' => array (
                    'condition' =>  ($aLinkInfo['item_img_src']),
                    'content'   => array (
                        'item_img_src'      => $aLinkInfo['item_img_src'],
                        'item_img_alt'      => $aLinkInfo['item_title'],
                        'item_img_width'    => ($aLinkInfo['item_img_width'])  ? $aLinkInfo['item_img_width']  : 16,
                        'item_img_height'   => ($aLinkInfo['item_img_height']) ? $aLinkInfo['item_img_height'] : 16,
                    ),
                ),

                'item_link'     => $aLinkInfo['item_link'],
                'item_onclick'  => ($aLinkInfo['item_onclick']) ? ' onclick="' . $aLinkInfo['item_onclick'] . ';return false"' : null,
                'item_title'    => $aLinkInfo['item_title'],

                'extra_info'    => ($aLinkInfo['extra_info']) ? ' (' . $aLinkInfo['extra_info'] . ')' : null,
            );

            $sOutputCode = $oSysTemplate -> parseHtmlByName( 'member_menu_sub_item.html', $aTemplateKeys );
            return $sOutputCode;
        }

        /**
         * Function will generate description window for menu's items;
         *
         * @param  : $sDescription (string) - item's description;
         * @return : Html presentation data;
         */
        function getDescriptionWindow($sDescription)
        {
            global $oSysTemplate;

            $aTemplateKeys = array(
                'description' => $sDescription,
            );

            $sOutputCode = $oSysTemplate -> parseHtmlByName( 'member_menu_descr_window.html', $aTemplateKeys );
            return $sOutputCode;
        }

        /**
         * Function will generate extra navigation menu for logged member ;
         *
         * @param : $memberID ( integer )   - member's ID ;
         * @param : $sPosition ( string )   - memeber menu section (possible values : 'top', 'top_extra') ;
         * @param : $bStructure ( boolean ) - if isset this param that function will return array ;
         * @return : Html presentation data or array with menu's structure;
        */
        function genMemberMenu( $memberID = 0, $sPosition, $bStructure = false ) 
    	{
    		global $oSysTemplate, $oFunctions;

    		// ** init some needed variables ;

            $oPermalinks   = new BxDolPermalinks();
    		$oUserStatus   = new BxDolUserStatusView();
            $sMemberStatus = $oUserStatus -> getStatusIcon($memberID) ;

    		$aMemberInfo = array();

            $sTemplateName = 'extra_top_menu.html';
    		$sOutputCode   = null;

    		// if member's id was defined, that will receive all member's info ;
            if ($memberID) {
                $aMemberInfo  =  getProfileInfo($memberID);
                $aMemberInfo['ProfileLink'] = getProfileLink($aMemberInfo['ID']);
            }

            // if member not logged ;
            if (!$aMemberInfo) {
                return ;
            }

    		// read data from cache file ;
            if( file_exists($this -> sMenuCacheFile) && filesize($this -> sMenuCacheFile) ) {
                $aMenuStructure =  unserialize(file_get_contents($this -> sMenuCacheFile));
            }
            else {
                // generate menu structure ;
    			$aMenuStructure = $this -> createMemberMenuCache($sPosition);
            }

    		if( !isset($aMenuStructure[$sPosition]) ) {
    			$aMenuStructure = $this ->  createMemberMenuCache($sPosition);
            }

    		// generate the menu's structure ;
    		if ( isset($aMenuStructure[$sPosition]) ) {
    			// replace all special markers ;
    			$aReplaced 	= array();
    			foreach( $aMenuStructure[$sPosition] AS $iKey => $aItems )
    			{
    				foreach($aItems AS $sKey => $sValue )
    				{
    					if ( $sKey != 'PopupMenu' && $sKey != 'linked_items' ) {
                            if ( $sKey == 'Caption' ) {
        						$aReplaced[$iKey][$sKey] = $oFunctions -> markerReplace($aMemberInfo, $sValue, $aItems['Eval'], true);
        					}
                            else {
        						$aReplaced[$iKey][$sKey] = $oFunctions -> markerReplace($aMemberInfo, $sValue, $aItems['Eval']);
                            }
                        }
                        else {
                            $aReplaced[$iKey][$sKey] = $sValue;
                        }
                    }
    			}

    			// generate menu's structure ;
    			$iIndex = 0; 
    			foreach( $aReplaced AS $iKey => $aItems )
    			{
                    // collect the link;
    				if ( $aItems['Type'] == 'link' && $aItems['Caption'] 
                        && ($aItems['Link'] || $aItems['Script']) ) {

                        $sPartCaption = $aItems['Caption'];
                        
    					// define some settings for member's block ;
                        $sMenuImage = ( $aItems['Name'] == 'MemberBlock' ) ? getTemplateIcon($sMemberStatus) : getTemplateIcon($aItems['Icon']);
    					$sItemImgId = ( $aItems['Name'] == 'MemberBlock' ) ? 'current_members_status_img' : null;
                        $sReduceImg = ( $aItems['Name'] != 'MemberBlock' ) ? $sMenuImage : null;

                        if($aItems['Caption'] == '{system}') {
                            $sMenuImage = $aItems['Icon'] ? getTemplateIcon($aItems['Icon']) : getTemplateIcon('spacer.gif');
                            $sPartCaption = eval($aItems['Eval']);
                        }

                        if ($aItems['Bubble']) {
                            $sCode  = str_replace('{iOldCount}', 0, $aItems['Bubble']);
                            $sCode  = str_replace('{ID}', $memberID, $sCode);

                            eval($sCode);
                            $this -> sBubbles .= "{$aItems['Name']} : {count:'{$aRetEval['count']}'}, \n";
                        }

                        $aMenuItems[$iIndex]	= array
    					(
    						// primary link's info ;
                            'menu_caption'		 => ( $aItems['Name'] == 'MemberBlock' || $aItems['Caption'] == '{system}') ? $sPartCaption : null,
    						'menu_link'			 => ( $aItems['Script'] ) ? 'javascript:void(0)' : $oPermalinks->permalink($aItems['Link']),
    						'extended_action'	 => ( $aItems['Script'] ) ? 'onclick="' . $aItems['Script'] . '"' : null,
    						'target'			 => ( $aItems['Target'] == '_blank' ) ? 'target="_blank"' : null,
    						'menu_image'		 => $sMenuImage,
    						'bubble_box'		 => ( $aItems['Bubble'] ) 
                                                        ? $oSysTemplate -> parseHtmlByName( 'member_menu_bubble.html', 
                                                            array(
                                                                'extra_styles' => ( $aRetEval['count'] ) ? null : 'style="display:none"', 
                                                                'count' => $aRetEval['count'], 
                                                                'bubble_id' => $this -> sBubblePrefix . $aItems['Name'])) 
                                                        : null,

                            'indent'             => ( $this -> sMemberMenuPosition  == 'bottom' )  ? 'menu_item_bottom' : 'menu_item_top',
                            'item_link_indent'   => ( $this -> sMemberMenuPosition  == 'bottom' )  ? 'bottom_indent' : 'top_indent',

                            // init block id if nedded;
                            'bx_if:item_id' => array (
                                'condition' =>  ( $sItemImgId ),
                                'content'   => array (
                                    'item_img_id'        => $sItemImgId,
                                ),
                            ),

                            'menu_id' => $aItems['ID'],

                            // menu description ;
                            'bx_if:menu_desc' => array(
                                'condition' => ($aItems['Description']),
                                'content'   => array (
                                   'menu_id'     => $aItems['ID'],
                                   'desc_window' => $this -> getDescriptionWindow( _t($aItems['Description']) ),
                                   'desc_indent' => ( $this -> sMemberMenuPosition  == 'bottom' ) ? 'description_bottom' : 'description_top',
                                ),
                            ),
                        );

                        if($aItems['Caption'] == '{system}') {
                            $sPartCaption = _t($aItems['Description']);
                        }

                        // define top menu's popup section ;
                        $aContentKeys = array (
                            'menu_id'     => $aItems['ID'],

                            // draw reduce element by top side ;
                            'bx_if:reduce_element_top' => array (
                                'condition' =>  ( $this -> sMemberMenuPosition  == 'bottom' ),
                                'content'   => array (
                                    'menu_id'               => $aItems['ID'],
                                    'item_link'             => $aMenuItems[$iIndex]['menu_link'],
                                    'extended_action' => $aMenuItems[$iIndex]['extended_action'],
                                    'cover'                 => 'top_cover',
                                    'item_name'             => $sPartCaption,

                                    'bx_if:part_image' => array(
                                        'condition' => ($sReduceImg),
                                        'content'   => array(
                                            'item_img_src'          => $sReduceImg,
                                            'cleared_item_name' => strip_tags($aItems['Caption']),
                                        ),
                                    ),
                                ),
                            ),

                            // draw reduce element by top side ;
                            'bx_if:reduce_element_bottom' => array (
                                'condition' =>  ( $this -> sMemberMenuPosition  == 'top' || $this -> sMemberMenuPosition  == 'static' ),
                                'content'   => array (
                                    'menu_id'         => $aItems['ID'],
                                    'item_link'       => $aMenuItems[$iIndex]['menu_link'],
                                    'extended_action' => $aMenuItems[$iIndex]['extended_action'],
                                    'cover'           => 'bottom_cover',
                                    'item_name'       => $sPartCaption,

                                    'bx_if:part_image' => array(
                                        'condition' => ($sReduceImg),
                                        'content'   => array(
                                            'item_img_src'          => $sReduceImg,
                                            'cleared_item_name' => strip_tags($aItems['Caption']),
                                        ),
                                    ),
                                ),
                            ),
                        );

                        if ( $aItems['PopupMenu'] ) {
                            $aMenuItems[$iIndex]['menu_link']       = 'javascript:void(0)';
                            $aMenuItems[$iIndex]['extended_action'] = null;
                        }

                        switch( $sPosition ) {

                            case 'top' :
                                  $aMenuItems[$iIndex]['bx_if:sub_menu'] = array (
                                    'condition'  => $aItems['PopupMenu'],
                                    'content'    =>  $aContentKeys,
                                );
                            break;

                            case 'top_extra' :
                                $aMenuItems[$iIndex]['bx_if:sub_menu_extra'] = array (
                                    'condition'  => $aItems['PopupMenu'],
                                    'content'    => $aContentKeys,
                                ); 
                            break;

                        }

    					$iIndex++;
    				}                   
         
    			}
    		}

            if ( $bStructure) {
                // return menu's structure ;
                return $aMenuItems;
            }

            // return builded menu ;
            $aTemplateKeys = array (
                'bx_repeat:items' => $aMenuItems,
            );

            // fill array with extra keys ;
            if ( $sPosition == 'top' ) {
                $aTemplateKeys['site_url']          =  BX_DOL_URL_ROOT;

                $aTemplateKeys['menu_position']     = $this -> sMemberMenuPosition; 
                $aTemplateKeys['is_profile_page']   = ( defined('BX_PROFILE_PAGE') ) ? 'true' : 'false' ;

                // define the top extra section ;
                $aExtraItems =  $this -> genMemberMenu( $memberID, 'top_extra', true ) ;
                if ( !empty($aExtraItems['menu_caption'])) {
                    $aExtraItems['menu_caption'] = strip_tags($aExtraItems['menu_caption']);
                }

                // define the extra section ;
                $aTemplateKeys['bx_repeat:extra_items'] = $aExtraItems;
                $aTemplateKeys['bubbles_list']          = preg_replace('/,$/', '', trim($this -> sBubbles) );
                $aTemplateKeys['bubbles_update_time']   = $this -> iBubblesUpdateTime;
                $aTemplateKeys['notify_destroy_time']   = $this -> iNotifyDestroyTime;
                $aTemplateKeys['page_reciver']          = $this -> sQueryPageReciver;
                $aTemplateKeys['bubble_prefix']         = $this -> sBubblePrefix;
            }

            $sOutputCode = $oSysTemplate -> parseHtmlByName( $sTemplateName, $aTemplateKeys );

            if (  $sPosition == 'top' ) { 
                $sOutputCode = $oSysTemplate -> addJs('user_status.js', true) . $sOutputCode;
            }

    		return $sOutputCode;
        }

        /**
         * Function will return menu's sub content;
         *
         * @param  : $iMemberId (integer) - logged member's Id;
         * @param  : $sSubMenuCode (string)  - sub menu's php code;
         * @param  : $aLinkedItems (array)   - linked links items;
         * @return : Html presentation data; 
         */
        function getSubMenuContent( $iMemberId, $sSubMenuCode, $aLinkedItems = array() )
        {
            global $oFunctions;

            $iMemberId = (int) $iMemberId;

            $aMemberInfo  = getProfileInfo($iMemberId);
            $sSubMenuCode = eval( $oFunctions -> markerReplace( $aMemberInfo, $sSubMenuCode) ); 

            if($aLinkedItems) {
                foreach($aLinkedItems as $iKey => $aItems)
                {
                    $sSubMenuCode .= eval( $oFunctions -> markerReplace( $aMemberInfo, $aItems['code']) );
                }
            }

            return $sSubMenuCode;
        }

        /**
         * @description : function will create menu's cache file ;
         * @param		: $sMenuSection ( string ) - section of menu ;
        */
        function createMemberMenuCache($sMenuSection) 
        {
        	$sMenuSection = process_db_input($sMenuSection);
            $oPermalink = new BxDolPermalinks();
        	$aCacheData = array();

        	$sQuery =
            "
                SELECT 
                    *
                FROM 
                    `sys_menu_member` 
                WHERE 
                    `Position` = '" . $sMenuSection . "' 
                        AND 
                    `Active` = '1' 
                ORDER BY 
                    `Order`
            ";

        	$rResult = db_res($sQuery);
            while( true == ($aRow = mysql_fetch_assoc($rResult)) ) 
            {
        	    $aRow['Link'] = $oPermalink -> permalink($aRow['Link']);
                $aRow['linked_items'] = $this -> getLinkedItem($aRow['ID']);

        		$aCacheData[$sMenuSection][$aRow['ID']] = $aRow;
        	}

            // if items not found ;
            if ( !mysql_num_rows($rResult) ) {
                $aCacheData[$sMenuSection] = array();
            }

        	// write data into cache file	
        	$aCurrentData = array();
        	if( file_exists($this -> sMenuCacheFile) ) {
        		$aCurrentData = unserialize(file_get_contents($this -> sMenuCacheFile));
                $aCurrentData = array_merge($aCurrentData, $aCacheData);
            }
        	else 
                $aCurrentData = $aCacheData;

            if( !empty($aCurrentData) && is_array($aCurrentData)) {
            	$rHandle = fopen($this -> sMenuCacheFile, 'w'); 
            	fwrite($rHandle, serialize($aCurrentData));
            	fclose($rHandle);
            }

        	return $aCurrentData;
        }

        /**
         * Function will get all linked item for recived menu's item;
         * 
         * @param  : $iMenuId (integer) - menu's Id;
         * @return : (array);
                [code] - (string) evaluate code;
         */
        function getLinkedItem($iMenuId)
        {
        	$iMenuId = (int) $iMenuId;
            $sQuery  = "SELECT `Eval` FROM `sys_menu_member` WHERE `Parent` = {$iMenuId} AND `Type` = 'linked_item'";
            $rResult = db_res($sQuery);

            $aLinkedItems = array();
            while ( true == ($aRow = mysql_fetch_assoc($rResult)) ) 
            {
                $aLinkedItems[] = array(
                    'code' => $aRow['Eval']
                );
            }

            return $aLinkedItems;
        }
    }
